aboutsummaryrefslogtreecommitdiff
path: root/html/options_main.js
diff options
context:
space:
mode:
authorWojtek Kosior <wk@koszkonutek-tmp.pl.eu.org>2021-05-12 17:41:08 +0200
committerWojtek Kosior <wk@koszkonutek-tmp.pl.eu.org>2021-05-12 17:41:08 +0200
commitf6a7f24e61a78f197250875ac9833f497a455d20 (patch)
tree9549ac201aeb8f8ed1cfef6270bae9c459476577 /html/options_main.js
parent55fb3e4bd833f042a82657cc75e7e4c657402f9e (diff)
downloadbrowser-extension-f6a7f24e61a78f197250875ac9833f497a455d20.tar.gz
browser-extension-f6a7f24e61a78f197250875ac9833f497a455d20.zip
rename "bundles" to "bags"
Diffstat (limited to 'html/options_main.js')
-rw-r--r--html/options_main.js16
1 files changed, 8 insertions, 8 deletions
diff --git a/html/options_main.js b/html/options_main.js
index ca591d5..104f771 100644
--- a/html/options_main.js
+++ b/html/options_main.js
@@ -92,7 +92,7 @@
/*
* Used to construct and update components list of edited
* bundle as well as edited page.
*/
function add_components(ul, components)
{
@@ -114,7 +114,7 @@
components_ul.appendChild(ul.work_empty_component_li);
}
/* Used to reset edited bundle as well as edited page. */
function generic_reset_work_li(ul, item, components)
{
if (item === undefined) {
@@ -138,7 +138,7 @@
generic_reset_work_li(ul, item, settings?.components);
}
/* Used to get edited bundle as well as edited page data for saving. */
function generic_work_li_data(ul)
{
let components_ul = ul.work_name_input.nextElementSibling;
@@ -305,11 +305,11 @@
state : UL_STATE.IDLE,
edited_item : undefined,
},
- [TYPE_PREFIX.BUNDLE] : {
- ul : by_id("bundles_ul"),
- work_li : by_id("work_bundle_li"),
- work_name_input : by_id("bundle_name_field"),
- work_empty_component_li : by_id("empty_bundle_component_li"),
+ [TYPE_PREFIX.BAG] : {
+ ul : by_id("bags_ul"),
+ work_li : by_id("work_bag_li"),
+ work_name_input : by_id("bag_name_field"),
+ work_empty_component_li : by_id("empty_bag_component_li"),
reset_work_li : generic_reset_work_li,
get_work_li_data : generic_work_li_data,
state : UL_STATE.IDLE,
@@ -92,7 +92,7 @@
/*
* Used to construct and update components list of edited
- * bundle as well as edited page.
+ * bag as well as edited page.
*/
function add_components(ul, components)
@@ -114,7 +114,7 @@
components_ul.appendChild(ul.work_empty_component_li);
}
- /* Used to reset edited bundle as well as edited page. */
+ /* Used to reset edited bag as well as edited page. */
function generic_reset_work_li(ul, item, components)
{
@@ -138,7 +138,7 @@
generic_reset_work_li(ul, item, settings?.components);
}
- /* Used to get edited bundle as well as edited page data for saving. */
+ /* Used to get edited bag as well as edited page data for saving. */
function generic_work_li_data(ul)
{